@@ -17,46 +17,19 @@
 (require 'ai-code-input)
 (require 'ai-code-prompt-mode)
 
-
 (declare-function ai-code-read-string "ai-code-input")
-(declare-function ai-code--get-context-files-string "ai-code-input")
-(declare-function ai-code--insert-prompt "ai-code-prompt-mode" (prompt-text))
 (declare-function ai-code--process-word-for-filepath "ai-code-prompt-mode" (word git-root-truename))
 (declare-function ai-code-call-gptel-sync "ai-code-prompt-mode" (prompt))
-(declare-function ai-code--resolve-auto-test-suffix-for-send "ai-code")
-(declare-function ai-code-backends-infra--session-buffer-p "ai-code-backends-infra" (buffer))
-(declare-function projectile-project-root "projectile")
-(declare-function ai-code-run-test "ai-code-agile")
-
-(defun ai-code--git-root (&optional dir)
-  "Return the normalized Git repository root path, or nil.
-Calls `magit-toplevel' with optional DIR argument and applies
-`file-truename' to resolve symlinks.  Returns nil when not inside
-a Git repository or when `magit-toplevel' signals an error."
-  (condition-case nil
-      (let ((root (magit-toplevel dir)))
-        (when root (file-truename root)))
-    (error nil)))
 
 (defcustom ai-code-sed-command "sed"
   "GNU sed command used to apply prompts to files."
   :type 'string
   :group 'ai-code)
 
-;; Variables that will be defined in ai-code.el
+;; Variables that will be defined in ai-code-interface.el
 (defvar ai-code-use-prompt-suffix)
 (defvar ai-code-prompt-suffix)
-(defvar ai-code-auto-test-type)
-(defvar ai-code-auto-test-suffix)
 (defvar ai-code-cli)
-(defvar ai-code-selected-backend)
-(defvar ai-code-task-use-gptel-filename)
-
-(defun ai-code--resolve-auto-test-suffix-for-current-send ()
-  "Return auto test suffix for this send action in file operations."
-  (if (fboundp 'ai-code--resolve-auto-test-suffix-for-send)
-      (ai-code--resolve-auto-test-suffix-for-send)
-    ai-code-auto-test-suffix))
 
 ;;;###autoload
 (defun ai-code-copy-buffer-file-name-to-clipboard (&optional arg)
@@ -76,7 +49,8 @@ with @ prefix if within git repo."
            (magit-get-current-branch))
           ;; If current buffer is a file, use existing logic
           ((buffer-file-name)
-           (let ((git-root-truename (ai-code--git-root)))
+           (let* ((git-root (magit-toplevel))
+                  (git-root-truename (when git-root (file-truename git-root))))
              (if (use-region-p)
                  (let ((processed-file (if (and git-root-truename (not arg))
                                            (ai-code--process-word-for-filepath (buffer-file-name) git-root-truename)
@@ -90,7 +64,8 @@ with @ prefix if within git repo."
           ;; If current buffer is a dired buffer
           ((derived-mode-p 'dired-mode)
            (let* ((file-at-point (ignore-errors (dired-get-file-for-visit)))
-                  (git-root-truename (ai-code--git-root)))
+                  (git-root (magit-toplevel))
+                  (git-root-truename (when git-root (file-truename git-root))))
              (if file-at-point
                  ;; If there's a file under cursor, copy its processed path
                  (if (and git-root-truename (not arg))
@@ -132,9 +107,6 @@ contains a directory path, open it directly in Dired in another window."
 (defvar ai-code-run-file-history nil
   "History list for `ai-code-run-current-file' commands.")
 
-(defvar ai-code-shell-command-history nil
-  "History list for shell command prompts.")
-
 (defun ai-code--run-command-in-comint (command run-directory display-name)
   "Run COMMAND in a comint buffer using RUN-DIRECTORY and DISPLAY-NAME.
 COMMAND is parsed into a program and its SWITCHES using
@@ -217,19 +189,10 @@ buffer.  It constructs a shell command:
 sed \"1i <prompt>: \" <file> | <ai-code-cli>
 and runs it in a compilation buffer."
   (interactive)
-  (when (eq (and (boundp 'ai-code-selected-backend)
-                 ai-code-selected-backend)
-            'agent-shell)
-    (user-error "Backend 'agent-shell' does not support piping file content via ai-code-cli"))
   (let* ((prompt (ai-code-read-string "Prompt: "))
-         (suffix-parts (delq nil (list ai-code-prompt-suffix
-                                       (when ai-code-auto-test-type
-                                         (ai-code--resolve-auto-test-suffix-for-current-send)))))
-         (suffix (when (and ai-code-use-prompt-suffix suffix-parts)
-                   (string-join suffix-parts ", ")))
-         (prompt-with-suffix (if suffix
-                                 (concat prompt ", " suffix)
-                               prompt))
+         (prompt-with-suffix (if (and ai-code-use-prompt-suffix ai-code-prompt-suffix)
+                                 (concat prompt ", " ai-code-prompt-suffix)
+                                 prompt))
          (file-name (cond
                      ((derived-mode-p 'dired-mode)
                       (dired-get-filename))
@@ -256,8 +219,7 @@ and runs it in a compilation buffer."
 Read initial command from user with INITIAL-INPUT as default.
 If command starts with ':', treat as prompt for AI to generate command.
 Return the final command string."
-  (let* ((initial-command (read-string "Shell command: " initial-input
-                                       'ai-code-shell-command-history))
+  (let* ((initial-command (ai-code-read-string "Shell command: " initial-input))
          ;; if current buffer is Dired buffer, replace the * character
          ;; inside initial-command with file base name under cursor,
          ;; or marked files, separate with space
@@ -361,77 +323,6 @@ is active; otherwise run the current file."
    (t
     (ai-code-run-current-file))))
 
-;;;###autoload
-(defun ai-code-build-or-test-project ()
-  "Build or test the current project based on user choice.
-If user chooses to build, check for build.sh in the project root
-and send to AI for execution. Otherwise, ask AI to generate a build command.
-If user chooses to test the whole project, call `ai-code-test-project'.
-If user chooses scoped testing, call `ai-code-run-test'."
-  (interactive)
-  (let ((action (completing-read "Choose action: " '("Build project" "Test project" "Test on scope") nil t)))
-    (cond
-     ((string= action "Build project") (ai-code-build-project))
-     ((string= action "Test project") (ai-code-test-project))
-     ((string= action "Test on scope") (ai-code-run-test)))))
-
-(defun ai-code--project-root ()
-  "Return the current project root using Projectile first, then Git."
-  (or (and (fboundp 'projectile-project-root)
-           (ignore-errors (projectile-project-root)))
-      (ai-code--git-root)))
-
-;;;###autoload
-(defun ai-code-build-project ()
-  "Build the current project.
-Check for build.sh in the project root and send to AI for execution.
-Otherwise, ask AI to generate a build command."
-  (interactive)
-  (let* ((proj-root (ai-code--project-root))
-         (build-script (when proj-root (expand-file-name "build.sh" proj-root)))
-         (repo-context (ai-code--format-repo-context-info))
-         (error-handling-instruction
-          (concat "\n\nIf the build fails:"
-                  "\n1. Analyze the error output carefully to identify the failure point"
-                  "\n2. Investigate the root cause by examining relevant source files"
-                  "\n3. Provide a clear explanation of what went wrong"
-                  "\n4. Suggest specific code fixes for user approval before making any changes"))
-         (initial-input
-          (if (and proj-root build-script (file-exists-p build-script))
-              ;; build.sh exists, ask AI to run it
-              (concat "Run the build script and report the results. "
-                      (format "\nProject root: %s" proj-root)
-                      (format "\nBuild script: %s" build-script)
-                      (when repo-context (concat "\n" repo-context))
-                      error-handling-instruction)
-            ;; No build.sh, ask AI to generate build command
-            (concat "Build the current project. Provide the build command and execute it if possible. "
-                    (when proj-root (format "\nProject root: %s" proj-root))
-                    (when repo-context (concat "\n" repo-context))
-                    error-handling-instruction)))
-         (prompt (ai-code-read-string "Send to AI: " initial-input)))
-    (ai-code--insert-prompt prompt)))
-
-;;;###autoload
-(defun ai-code-test-project ()
-  "Ask AI to run test on the whole project and provide failure analysis."
-  (interactive)
-  (let* ((proj-root (ai-code--project-root))
-         (repo-context (ai-code--format-repo-context-info))
-         (failure-follow-up
-          (concat "\n\nIf test fails:"
-                  "\n1. Analyze the test results to identify failing tests and failure points"
-                  "\n2. Investigate likely root causes by checking related source and test files"
-                  "\n3. Explain what failed and why in clear terms"
-                  "\n4. Provide specific code fix suggestions for user approval before making any changes"))
-         (initial-input
-          (concat "Run test on the whole project and report the results."
-                  (when proj-root (format "\nProject root: %s" proj-root))
-                  (when repo-context (concat "\n" repo-context))
-                  failure-follow-up))
-         (prompt (ai-code-read-string "Send to AI: " initial-input)))
-    (ai-code--insert-prompt prompt)))
-
 (defvar ai-code--repo-context-info (make-hash-table :test #'equal)
   "Hash table storing context info lists per Git repository root.")
 
@@ -449,35 +340,8 @@ When no region is selected, use the full file path and current function
 \(if any).  When a region is active, use the file path with line range
 in the form filepath#Lstart-Lend."
   (interactive)
-  (let* ((current-root (ai-code--git-root))
-         (all-roots (let ((roots '()))
-                      (walk-windows
-                       (lambda (w)
-                         (with-current-buffer (window-buffer w)
-                           (let ((root (ai-code--git-root)))
-                             (when (and root (not (member root roots)))
-                               (push root roots)))))
-                       nil 'current-frame)
-                      (when (fboundp 'ai-code-backends-infra--session-buffer-p)
-                        (dolist (buf (buffer-list))
-                          (when (ai-code-backends-infra--session-buffer-p buf)
-                            (with-current-buffer buf
-                              (let ((root (ai-code--git-root)))
-                                (when (and root (not (member root roots)))
-                                  (push root roots)))))))
-                      (nreverse roots)))
-         (ordered-roots (if (and current-root (member current-root all-roots))
-                            (cons current-root (remove current-root all-roots))
-                          all-roots))
-         (repo-root (cond
-                     ((null ordered-roots)
-                      (user-error "Not inside a Git repository"))
-                     ((= (length ordered-roots) 1)
-                      (car ordered-roots))
-                     (t
-                      (completing-read "Select Git repository for context: "
-                                       ordered-roots
-                                       nil t nil nil (car ordered-roots))))))
+  (let ((repo-root (or (magit-toplevel)
+                       (user-error "Not inside a Git repository"))))
     (if (derived-mode-p 'dired-mode)
         (let* ((all-marked (dired-get-marked-files))
                (file-at-point (dired-get-filename nil t))
@@ -542,7 +406,7 @@ With prefix ARG, clear all repositories."
       (progn
         (clrhash ai-code--repo-context-info)
         (message "Cleared all stored context info."))
-    (let ((repo-root (or (ai-code--git-root)
+    (let ((repo-root (or (magit-toplevel)
                          (user-error "Not inside a Git repository"))))
       (if (gethash repo-root ai-code--repo-context-info)
           (progn
@@ -550,29 +414,25 @@ With prefix ARG, clear all repositories."
             (message "Cleared context info for %s." repo-root))
         (message "No context info stored for %s." repo-root)))))
 
-(defun ai-code-context-action (_arg)
-  "Add, show, or clear context entries via `completing-read'.
-Presents a menu with three choices: Add context, Show context, or
-Clear context.  The prefix argument ARG is ignored."
+(defun ai-code-context-action (arg)
+  "Add or clear context entries depending on ARG.
+Without prefix ARG, add context and immediately list all stored entries.
+With prefix ARG \[universal-argument], clear context; clearing the
+current repo or all repos is delegated to `ai-code-clear-context'."
   (interactive "P")
-  (let ((action (completing-read "Context action: "
-                                 '("Add context" "Show context" "Clear context")
-                                 nil t)))
-    (pcase action
-      ("Add context"
-       (call-interactively #'ai-code-add-context)
-       (ai-code-list-context))
-      ("Show context"
-       (ai-code-list-context))
-      ("Clear context"
-       (call-interactively #'ai-code-clear-context)))))
+  (if arg
+      (call-interactively #'ai-code-clear-context)
+    (call-interactively #'ai-code-add-context)
+    (ai-code-list-context)))
 
 (defun ai-code--format-repo-context-info ()
   "Return formatted repository context string or nil.
 Includes stored context entries for the current Git repository if available."
   (when (and (boundp 'ai-code--repo-context-info)
              ai-code--repo-context-info)
-    (let ((repo-root (ai-code--git-root)))
+    (let ((repo-root (condition-case nil
+                         (magit-toplevel)
+                       (error nil))))
       (when repo-root
         (let ((entries (gethash repo-root ai-code--repo-context-info)))
           (when entries
@@ -605,77 +465,6 @@ toggle dedication for every window in the current frame."
         (message "Window dedication updated: %s" (mapconcat #'identity (nreverse results) ", "))
       (message "No file buffers found in target windows"))))
 
-(defun ai-code--sanitize-generated-path-name (name)
-  "Sanitize generated NAME for file or directory creation."
-  (let ((clean-name (downcase (string-trim (or name "")))))
-    (setq clean-name (or (car (split-string clean-name "\n" t)) ""))
-    (setq clean-name (replace-regexp-in-string "[^a-z0-9._/-]" "_" clean-name))
-    (setq clean-name (replace-regexp-in-string "_+" "_" clean-name))
-    (setq clean-name (replace-regexp-in-string "/+" "/" clean-name))
-    (setq clean-name (replace-regexp-in-string "^[_./]+\\|[_./]+$" "" clean-name))
-    clean-name))
-
-(defun ai-code--generate-file-or-dir-name-with-gptel (description target-type)
-  "Generate a file or directory name for DESCRIPTION and TARGET-TYPE.
-TARGET-TYPE should be either \"file\" or \"directory\"."
-  (let* ((prompt
-          (format
-           (concat "Generate one concise lowercase %s name for this request: %s\n"
-                   "Rules: return only the name, no explanation, no markdown, no quotes, max 60 chars.\n"
-                   "Use letters/numbers/_/./- and / for nested path if needed.")
-           target-type
-           description))
-         (generated-name (condition-case nil
-                             (ai-code-call-gptel-sync prompt)
-                           (error description))))
-    (ai-code--sanitize-generated-path-name generated-name)))
-
-;;;###autoload
-(defun ai-code-create-file-or-dir ()
-  "Generate and create a new file or directory under current directory.
-Use GPTel to generate the name, ask user to confirm, then create and open
-it in another window."
-  (interactive)
-  (let* ((current-dir (if (derived-mode-p 'dired-mode)
-                          (dired-current-directory)
-                        default-directory))
-         (target-type (completing-read "Create target type: "
-                                       '("file" "directory")
-                                       nil t nil nil "file"))
-         (description (read-string (format "Describe the %s to create: " target-type))))
-    (when (string-empty-p (string-trim description))
-      (user-error "Description cannot be empty"))
-    (let* ((generated-name (if (and (boundp 'ai-code-task-use-gptel-filename)
-                                    ai-code-task-use-gptel-filename)
-                               (ai-code--generate-file-or-dir-name-with-gptel description target-type)
-                             (ai-code--sanitize-generated-path-name description)))
-           (fallback-name (if (string-empty-p generated-name)
-                              (if (string= target-type "directory")
-                                  "new_dir"
-                                "new_file.txt")
-                            generated-name))
-           (confirmed-name
-            (read-string (format "Confirm %s name (will create under %s): "
-                                 target-type
-                                 (abbreviate-file-name current-dir))
-                         fallback-name))
-           (sanitized-name (ai-code--sanitize-generated-path-name confirmed-name)))
-      (when (string-empty-p sanitized-name)
-        (user-error "Confirmed name cannot be empty"))
-      (let ((target-path (expand-file-name sanitized-name current-dir)))
-        (if (string= target-type "directory")
-            (progn
-              (unless (file-directory-p target-path)
-                (make-directory target-path t))
-              (dired-other-window target-path)
-              (message "Opened directory: %s" target-path))
-          (progn
-            (unless (file-exists-p target-path)
-              (make-directory (file-name-directory target-path) t)
-              (write-region "" nil target-path nil 'silent))
-            (find-file-other-window target-path)
-            (message "Opened file: %s" target-path)))))))
-
 (provide 'ai-code-file)
 
 ;;; ai-code-file.el ends here
