@@ -28,9 +28,6 @@ Candidate values:
   :group 'ai-code)
 
 (declare-function ai-code--insert-prompt "ai-code-prompt-mode" (prompt-text))
-(declare-function ai-code--ensure-files-directory "ai-code-prompt-mode" ())
-
-(defvar ai-code-files-dir-name)
 
 ;;;###autoload
 (defun ai-code-pull-or-review-diff-file ()
@@ -42,15 +39,11 @@ Otherwise, generate the diff."
       (let* ((file-name (file-name-nondirectory buffer-file-name))
              (init-prompt (format "Code review for %s. Use relevant file in repository as context.
 
-**Review Steps**:
-1. **Requirement Fit** (Top Priority): Verify if the code change fulfills the requirement below. Identify gaps or missing implementations.
-2. **Code Quality**: Check for quality, security, performance, and coding patterns.
-3. **Issues Found**: For each issue: Location, Issue, Solution, Priority (High/Medium/Low)
+**Focus**: Quality, security, performance, patterns
+**Format**: Location, issue, solution, priority (High/Medium/Low)
 
-Provide overall assessment.
-
-**Requirement**: " file-name))
-             (prompt (ai-code-read-string "Enter review prompt (type requirement at end): " init-prompt)))
+Provide overall assessment." file-name))
+             (prompt (ai-code-read-string "Enter diff review prompt: " init-prompt)))
         (ai-code--insert-prompt prompt))
     (ai-code--magit-generate-feature-branch-diff-file)))
 
@@ -182,20 +175,19 @@ DIFF-PARAMS is a plist with :type (`'commit`, `'base-vs-head`, `'branch-range`),
   (find-file diff-file)
   (message "Generated diff file: %s" diff-file))
 
-(defun ai-code--handle-staged-diff-generation (_git-root)
+(defun ai-code--handle-staged-diff-generation (git-root)
   "Handle generation of diff for staged change.
-_GIT-ROOT is unused but kept for API compatibility."
-  (let* ((files-dir (ai-code--ensure-files-directory))
-         (diff-file-name-part "staged")
-         (diff-file (expand-file-name (concat diff-file-name-part ".diff") files-dir)))
+GIT-ROOT is the root directory of the Git repository."
+  (let* ((diff-file-name-part "staged")
+         (diff-file (expand-file-name (concat diff-file-name-part ".diff") git-root)))
     (ai-code--generate-staged-diff diff-file)
     diff-file))
 
-(defun ai-code--handle-base-vs-head-diff-generation (_git-root
+(defun ai-code--handle-base-vs-head-diff-generation (git-root
                                                       &optional
                                                       open-in-browser)
   "Handle generation of diff between a base branch and HEAD.
-_GIT-ROOT is unused but kept for API compatibility.
+GIT-ROOT is the root directory of the Git repository.
 If OPEN-IN-BROWSER is non-nil, only open the diff in GitHub web
 interface without generating file."
   (let* ((base-branch (ai-code-read-string "Base branch name: "))
@@ -204,9 +196,8 @@ interface without generating file."
         (progn
           (ai-code--open-git-web-compare base-branch (or current-branch "HEAD"))
           nil)  ; Return nil since no file was generated
-      (let* ((files-dir (ai-code--ensure-files-directory))
-             (diff-file-name-part (concat (replace-regexp-in-string "/" "-" base-branch) ".HEAD"))
-             (diff-file (expand-file-name (concat diff-file-name-part ".diff") files-dir))
+      (let* ((diff-file-name-part (concat (replace-regexp-in-string "/" "-" base-branch) ".HEAD"))
+             (diff-file (expand-file-name (concat diff-file-name-part ".diff") git-root))
              (diff-params (list :type 'base-vs-head
                                 :base-branch base-branch
                                 :feature-branch "HEAD"
@@ -214,11 +205,11 @@ interface without generating file."
         (ai-code--generate-branch-or-commit-diff diff-params diff-file)
         diff-file))))
 
-(defun ai-code--handle-branch-range-diff-generation (_git-root
+(defun ai-code--handle-branch-range-diff-generation (git-root
                                                       &optional
                                                       open-in-browser)
   "Handle generation of diff between a base and a feature branch.
-_GIT-ROOT is unused but kept for API compatibility.
+GIT-ROOT is the root directory of the Git repository.
 If OPEN-IN-BROWSER is non-nil, only open the diff in GitHub web
 interface without generating file."
   (let* ((base-branch (ai-code-read-string "Base branch name: "))
@@ -237,11 +228,10 @@ interface without generating file."
               (if (consp raw-scope-choice)
                   (cdr raw-scope-choice)
                 (cdr (assoc raw-scope-choice scope-alist))))
-        (let* ((files-dir (ai-code--ensure-files-directory))
-               (diff-file-name-part (concat (replace-regexp-in-string "/" "-" base-branch)
+        (let* ((diff-file-name-part (concat (replace-regexp-in-string "/" "-" base-branch)
                                            "."
                                            (replace-regexp-in-string "/" "-" feature-branch)))
-               (diff-file (expand-file-name (concat diff-file-name-part ".diff") files-dir))
+               (diff-file (expand-file-name (concat diff-file-name-part ".diff") git-root))
                (diff-params (list :type 'branch-range
                                    :base-branch base-branch
                                    :feature-branch feature-branch
@@ -250,10 +240,10 @@ interface without generating file."
           (ai-code--generate-branch-or-commit-diff diff-params diff-file)
           diff-file)))))
 
-(defun ai-code--handle-commit-diff-generation (_git-root
+(defun ai-code--handle-commit-diff-generation (git-root
                                                 &optional open-in-browser)
   "Handle generation of diff for a single commit.
-_GIT-ROOT is unused but kept for API compatibility.
+GIT-ROOT is the root directory of the Git repository.
 If OPEN-IN-BROWSER is non-nil, only open the commit in GitHub web
 interface without generating file."
   (let* ((commit-hash (ai-code-read-string "Commit hash: ")))
@@ -261,11 +251,10 @@ interface without generating file."
         (progn
           (ai-code--open-git-web-commit commit-hash)
           nil)  ; Return nil since no file was generated
-      (let* ((files-dir (ai-code--ensure-files-directory))
-             (base-branch (concat commit-hash "^"))  ; Diff against parent
+      (let* ((base-branch (concat commit-hash "^"))  ; Diff against parent
              (feature-branch commit-hash)
              (diff-file-name-part commit-hash)
-             (diff-file (expand-file-name (concat diff-file-name-part ".diff") files-dir))
+             (diff-file (expand-file-name (concat diff-file-name-part ".diff") git-root))
              (diff-params (list :type 'commit
                                 :base-branch base-branch
                                 :feature-branch feature-branch
@@ -290,9 +279,9 @@ interface without generating file."
       (cdr (assoc raw-diff-type-choice diff-type-alist)))))
 
 ;;; New helper for commit ranges
-(defun ai-code--handle-commit-range-diff-generation (_git-root &optional open-in-browser)
+(defun ai-code--handle-commit-range-diff-generation (git-root &optional open-in-browser)
   "Handle generation of diff between two commits (commit range).
-_GIT-ROOT is unused but kept for API compatibility.
+GIT-ROOT is the repository root directory.
 If OPEN-IN-BROWSER is non-nil, only open the diff in GitHub web interface
 without generating file."
   (let* ((raw-start (ai-code-read-string "Start commit or branch: "))
@@ -304,18 +293,13 @@ without generating file."
         (progn
           (ai-code--open-git-web-compare start end)
           nil)  ; Return nil since no file was generated
-      ;; Sanitize branch names for file path (replace "/" with "-")
-      (let* ((files-dir (ai-code--ensure-files-directory))
-             (name-sanitized (concat (replace-regexp-in-string "/" "-" start)
-                                     ".."
-                                     (replace-regexp-in-string "/" "-" end)))
-             (file      (expand-file-name (concat name-sanitized ".diff") files-dir))
+      (let* ((name      (format "%s..%s" start end))
+             (file      (expand-file-name (concat name ".diff") git-root))
              ;; reuse branch-range plumbing (it will fetch and verify)
              (params    (list :type 'branch-range
                               :base-branch start
                               :feature-branch end
-                              :branch-scope 'remote  ; commit-range uses resolved refs
-                              :diff-file-name-part name-sanitized)))
+                              :diff-file-name-part name)))
         (ai-code--generate-branch-or-commit-diff params file)
         file))))
 
@@ -577,12 +561,12 @@ If not inside a Git repository, do nothing."
     (if (not git-root)
         (message "ai-code-update-git-ignore: not in a git repository, skipped")
       (let* ((gitignore-path (expand-file-name ".gitignore" git-root))
-             (required-entries (list (concat ai-code-files-dir-name "/")
+             (required-entries (list ai-code-prompt-file-name
+                                     ai-code-notes-file-name
                                      ".projectile"
                                      "GTAGS"
                                      "GRTAGS"
-                                     "GPATH"
-                                     "__pycache__/"))
+                                     "GPATH"))
              (gitignore-content (when (file-exists-p gitignore-path)
                                   (with-temp-buffer
                                     (insert-file-contents gitignore-path)
